;Filename: TCfg.s
;Part: ADuC7020,ADuC7024,ADuC7026.
;Created: 01/09/2004
;Updated: 28/06/2005
;Author: Barry Broderick
;This file is in beta sampling.

#include        <ADuC702x.IAR.equ>

; TCfg==========Configures timer T.
; C Function prototype: int TCfg(int iT, int iScale, int iTim);
;iT:{0,1,2,3}
;iScale:{1,16,256,32768}
;iTim:{T_HTim,T_OSC,T_SPM0,T_MRST}  (T1 only, use any value for other timers)
; Description of Function: Configures timer T.
; User interface:
;   Set iT to desired Timer, 0 to 3
;   Set iScale to a prescale value of 1, 16, 256 or 32768 (32768 in T1 and T2 only).
;   Set iTim to the desired clock source.
;       0 = T1_HTim -> HTim            2 = T1_SPM0 => P1.0 pin
;       1 = T1_OSC => 32.768kHz        3 = T1_MRST => P0.6 pin
;   Call TCfg().
;       Timer x is stopped in periodic mode and prescale set to iScale.
;   Returns previous TCON value in r0.
; Robustness:
;  FreeRunning mode not supported. Use periodic mode with reload value
;  of 0xffff (or 0xffffffff for T1) instead.
;  Certain features are not available for certain timers. Refer to the
;  data sheet for more information.
; Side effects: Corrupts r0, r1, r2 and r3.

                RSEG CODE
                MODULE TCfg
                PUBLIC TCfg
                CODE32

TCfg: stmfd   sp!,{r4}
      subs    r1,r1,#16                ;Compare r1 to 16
      movlt   r4,#0x40                 ; if lt set /1 and periodic
      moveq   r4,#0x44                 ; if 16 set /16 and periodic
      movgt   r4,#0x48                 ; if gt set /256 and periodic.
      cmpgt   r1,#256                  ;Compare r1 to 256
      movgt   r4,#0x4f                 ; if gt set /32768 and periodic.

      orr     r4,r4,r2,lsl#9           ;Move iTim into r4

      mov     r3,#0xff0000             ;r3 = Z_BASE;
      orr     r3,r3,#0xff000000      
      orr     r3,r3,r0,lsl#5           ;r3 = r0 << 5;

      ldr     r0,[r3,#Z_T0CON]         ;Get CON.
      str     r4,[r3,#Z_T0CON]         ;Write to CON
      ldmfd   sp!,{r4}
      bx      lr


                 ENDMOD  TCfg

                 END

